==> haskell-test-framework-leancheck-0.0.4-209.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-test-framework-leancheck.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 test-framework-leancheck
version:              0.0.4
visibility:           public
id:                   test-framework-leancheck-0.0.4-Genn3OAH4DHH3Lh7FJaiQX
key:                  test-framework-leancheck-0.0.4-Genn3OAH4DHH3Lh7FJaiQX
license:              BSD-3-Clause
maintainer:           Rudy Matela <rudy@matela.com.br>
author:               Rudy Matela <rudy@matela.com.br>
homepage:
    https://github.com/rudymatela/test-framework-leancheck#readme

synopsis:             LeanCheck support for test-framework.
description:
    LeanCheck support for test-framework.

    This package can be used to incorporate LeanCheck tests
    into test-framework test suites.

    Please see the Haddock documentation and README for more details.

category:             Testing
abi:                  1ec504ae277e21d75d74295c1e0a2aae
exposed:              True
exposed-modules:      Test.Framework.Providers.LeanCheck
import-dirs:
    /usr/lib/ghc-9.6.6/site-local/test-framework-leancheck-0.0.4

library-dirs:
    /usr/lib/ghc-9.6.6/site-local/test-framework-leancheck-0.0.4

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/test-framework-leancheck-0.0.4

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-test-framework-leancheck
hs-libraries:         HStest-framework-leancheck-0.0.4-Genn3OAH4DHH3Lh7FJaiQX
depends:
    base-4.18.2.1 leancheck-1.0.2-3Q5gjzA8lue3H9rlyJUOcN
    test-framework-0.8.2.2-ITHWZraIqyRCzzqSShCGFx

haddock-interfaces:
    /usr/share/doc/haskell-test-framework-leancheck/html/test-framework-leancheck.haddock

haddock-html:         /usr/share/doc/haskell-test-framework-leancheck/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-test-framework-leancheck-0.0.4-210-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-test-framework-leancheck.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 test-framework-leancheck
version:              0.0.4
visibility:           public
id:                   test-framework-leancheck-0.0.4-KGC7rVONrnGA2289LdUnkY
key:                  test-framework-leancheck-0.0.4-KGC7rVONrnGA2289LdUnkY
license:              BSD-3-Clause
maintainer:           Rudy Matela <rudy@matela.com.br>
author:               Rudy Matela <rudy@matela.com.br>
homepage:
    https://github.com/rudymatela/test-framework-leancheck#readme

synopsis:             LeanCheck support for test-framework.
description:
    LeanCheck support for test-framework.

    This package can be used to incorporate LeanCheck tests
    into test-framework test suites.

    Please see the Haddock documentation and README for more details.

category:             Testing
abi:                  ed69a412433597a3c1fa410c63ac2b6c
exposed:              True
exposed-modules:      Test.Framework.Providers.LeanCheck
import-dirs:
    /usr/lib/ghc-9.6.6/site-local/test-framework-leancheck-0.0.4

library-dirs:
    /usr/lib/ghc-9.6.6/site-local/test-framework-leancheck-0.0.4

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/test-framework-leancheck-0.0.4

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-test-framework-leancheck
hs-libraries:         HStest-framework-leancheck-0.0.4-KGC7rVONrnGA2289LdUnkY
depends:
    base-4.18.2.1 leancheck-1.0.2-3Q5gjzA8lue3H9rlyJUOcN
    test-framework-0.8.2.2-8fX8NEZ5OtDCOpAj0ijyRX

haddock-interfaces:
    /usr/share/doc/haskell-test-framework-leancheck/html/test-framework-leancheck.haddock

haddock-html:         /usr/share/doc/haskell-test-framework-leancheck/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
